##### Data from: Gametophyte niche differences among sympatric tree ferns (2018)
##### Authors: Brock, J; Burns, B; Perry, G; Lee, W

library(lme4)
library(s20x)
library(tidyverse)
library(ggplot2)
library(lmerTest)
library(predictmeans)

#### Import gametophyte data and tidy dataset

gam <- read.table("Pathway/glmm_mature.txt", sep="\t", header = TRUE)
gam$P <- as.factor(gam$P)
gam$L <- as.factor(gam$L)
gam$TrtComb <- paste(gam$Species, gam$P, gam$L, sep = ":")

#### Model gametophyte maturity values against treatment etc.

gam.mdl <- glmer(cbind(Mature, (Prop_G - Mature)) ~ P * Species * L  + (1 | TrtComb), data = gam, family = binomial)
summary(gam.mdl)

predictmeans(gam.mdl, modelterm = "P:Species:L", adj = "fdr", Df = 324)

#### Comparing germination rates

ger.mdl <- glmer(cbind(Prop_G, (100 - Prop_G)) ~ Species + (1 | TrtComb), data = gam, family = binomial)
summary(ger.mdl)

#### Mean germination values per spp.

sp.uni <- unique(gam$Species)

for(i in 1:length(sp.uni)){
  paste(print(as.character(sp.uni[i])),
  print(sd(gam[gam$Species == sp.uni[i],]$Prop_G)), sep = ":")
}

mean(gam[gam$Species == "CYAdea",]$Prop_G)

###### Comparing sporophyte orthophosphate values

P <- read.table("Pathway/sporo_p.txt", sep="\t", header = TRUE)
p.mdl <- lmer(p ~ species + (1 | grp), data = P)
summary(p.mdl)

qqnorm(residuals(p.mdl))
normcheck(residuals(p.mdl))